@@ -12,6 +12,7 @@ import magic
 from confluent_kafka import Producer
 from mobio.libs.Singleton import Singleton
 from mobio.libs.caching import LruCache
+from mobio.sdks.admin import MobioAdminSDK
 
 from .config import ConsumerTopic, MobioEnvironment, StoreCacheType, Cache
 from .constant import DirSaveFile, FieldConstantResponse, CONSTANT_MAP_FORMAT_FILE, ParamMessageSaveInfoFile, \
@@ -65,6 +66,12 @@ class MobioMediaSDK(object):
                 cache_prefix=cache_prefix,
                 redis_uri=redis_uri,
             )
+        MobioAdminSDK().config(
+            admin_host=self.admin_host,  # admin host
+            redis_uri=redis_uri,  # redis uri
+            module_use="MEDIA",  # liên hệ admin để khai báo tên của module
+            module_encrypt="OaFGfjB6zSvrZQx89Vzn6e120dca106438b69bc5521f757df80f",  # liên hệ admin để lấy mã
+        )
         conf = {
             "request.timeout.ms": 20000,
             "bootstrap.servers": MobioEnvironment.KAFKA_BROKER,
